@@ -54,9 +54,13 @@ struct _GVfsBackendMtp
   LIBMTP_mtpdevice_t *device;
   char *dev_path;
 
+  GHashTable *file_cache;
+
   GHashTable *monitors;
   guint hb_id;
   gint unmount_started;
+
+  gboolean android_extension;
 };
 
 struct _GVfsBackendMtpClass
